<div align="center">
  <img src=https://avatars.githubusercontent.com/u/113800422?s=200&v=4"><br>
</div>

-----------------
# HyTa - Technical Analysis Library

 ![](https://img.shields.io/badge/python-3.8-blue.svg) ![](https://img.shields.io/badge/python-3.9-blue.svg) ![](https://img.shields.io/badge/python-3.10-blue.svg) ![](https://img.shields.io/badge/python-3.11-blue.svg) ![unit tests](https://github.com/Hypance/HypanceDataAnalysis/blob/read.me/readme_docs/unittest.svg) 



<p align="center">
    <a href="/readme_docs/readme_fr.md">Français </a>
    ·
    <a href="/readme_docs/readme_cn.md">简体中文</a>
    ·
    <a href="/readme_docs/readme_es.md">Español</a>
    ·
    <a href="/readme_docs/readme_de.md">Deutsch</a>
    ·
    <a href="/readme_docs/readme_ja.md">日本語</a>
    ·
    <a href="/readme_docs/readme_pt-BR.md">Português Brasileiro</a>
    ·
    <a href="/readme_docs/readme_it.md">Italiano</a>
    ·
    <a href="/readme_docs/readme_kr.md">한국어</a>
    .
    <a href="/readme_docs/readme_nl.md">Nederlands</a>
    .
    <a href="/readme_docs/readme_np.md">नेपाली</a>
    .
    <a href="/readme_docs/readme_tr.md">Türkçe</a>
  </p>

-----------------

"Hyta" is a novel Python library that provides financial indicators for technical analysis, with a noteworthy emphasis on incremental computation. The library's incremental computation feature makes it particularly suitable for real-time applications or any other application that involves iterative input.

As a relatively new project, "hyta" is highly receptive to user feedback and suggestions for improving its API to meet users' unique needs.

---

### List of indicators

The current version of "hyta" includes a comprehensive set of indicators. However, if your preferred indicator is not included, you can create a ticket through GitHub Issues, and there is a high likelihood that it will be incorporated into a future version of the library.

- [Average Directional Index (ADX)](https://github.com/Hypance/HypanceDataAnalysis/blob/main/hyta/adx.py)
- [Aroon](https://github.com/Hypance/HypanceDataAnalysis/blob/main/hyta/aroon.py)
- [Average True Range (ATR)](https://github.com/Hypance/HypanceDataAnalysis/blob/main/hyta/atr.py)
- [Bollinger Bands](https://github.com/Hypance/HypanceDataAnalysis/blob/main/hyta/bollinger.py)
- [Commodity Channel Index (CCI)](https://github.com/Hypance/HypanceDataAnalysis/blob/main/hyta/cci.py)
- [Chaikin Money Flow (CMF)](https://github.com/Hypance/HypanceDataAnalysis/blob/main/hyta/cmf.py)
- [Chande Momentum Oscillator (CMO)](https://github.com/Hypance/HypanceDataAnalysis/blob/main/hyta/cmo.py)
- [Detrended Price Oscillator (DPO)](https://github.com/Hypance/HypanceDataAnalysis/blob/main/hyta/dpo.py)
- [Directional Movement Index (DX)](https://github.com/Hypance/HypanceDataAnalysis/blob/main/hyta/dx.py)
- [Exponential Moving Average (EMA)](https://github.com/Hypance/HypanceDataAnalysis/blob/main/hyta/ema.py)
- [Hull Moving Average (HMA)](https://github.com/Hypance/HypanceDataAnalysis/blob/main/hyta/hma.py)
- [Ichimoku Cloud](https://github.com/Hypance/HypanceDataAnalysis/blob/main/hyta/ichimoku_cloud.py)
- [Kaufman Adaptive Moving Average (KAMA)](https://github.com/Hypance/HypanceDataAnalysis/blob/main/hyta/kama.py)
- [Moving Average Convergence Divergence (MACD)](https://github.com/Hypance/HypanceDataAnalysis/blob/main/hyta/macd.py)
- [Money Flow Index (MFI)](https://github.com/Hypance/HypanceDataAnalysis/blob/main/hyta/mfi.py)
- [Momentum](https://github.com/Hypance/HypanceDataAnalysis/blob/main/hyta/momentum.py)
- [Moving Average](https://github.com/Hypance/HypanceDataAnalysis/blob/main/hyta/movingaverage.py)
- [On Balance Volume (OBV)](https://github.com/Hypance/HypanceDataAnalysis/blob/main/hyta/on_balance_volume.py)
- [Percentage Price Oscillator (PPO)](https://github.com/Hypance/HypanceDataAnalysis/blob/main/hyta/ppo.py)
- [Parabolic SAR (PSAR)](https://github.com/Hypance/HypanceDataAnalysis/blob/main/hyta/psar.py)
- [Rate of Change (ROC)](https://github.com/Hypance/HypanceDataAnalysis/blob/main/hyta/roc.py)
- [Relative Strength Index (RSI)](https://github.com/Hypance/HypanceDataAnalysis/blob/main/hyta/rsi.py)
- [Simple Moving Average (SMA)](https://github.com/Hypance/HypanceDataAnalysis/blob/main/hyta/SMA.py)
- [Stochastic Oscillator](https://github.com/Hypance/HypanceDataAnalysis/blob/main/hyta/Stochastic_Oscillator.py)
- [Triangular Moving Average (TMA)](https://github.com/Hypance/HypanceDataAnalysis/blob/main/hyta/tma.py)
- [True Strength Index (TSI)](https://github.com/Hypance/HypanceDataAnalysis/blob/main/hyta/tsi.py)
- [Ultimate Oscillator (UO)](https://github.com/Hypance/HypanceDataAnalysis/blob/main/hyta/uo.py)
- [Williams %R](https://github.com/Hypance/HypanceDataAnalysis/blob/main/hyta/williams_r.py)
- [Weighted Moving Average (WMA)](https://github.com/Hypance/HypanceDataAnalysis/blob/main/hyta/wma.py)



### Installation
```bash
pip install hyta
```

### Contact

- For the most efficient means of reporting issues, bugs, or corrections, as well as proposing new features, we highly suggest utilizing [GitHub Issues](https://github.com/Hypance/HypanceDataAnalysis/issues).